# frozen_string_literal: true

all

# Update line length to 120 chars.
rule 'MD013', line_length: 120

# Allow duplicate headings.
exclude_rule 'MD024'

# Allow trailing punctuation in headings.
exclude_rule 'MD026'

# Allow html tags
exclude_rule 'MD033'